'use strict';

const Gio = imports.gi.Gio;
const GLib = imports.gi.GLib;
const GObject = imports.gi.GObject;
const St = imports.gi.St;

const Main = imports.ui.main;
const PanelMenu = imports.ui.panelMenu;

const ExtensionUtils = imports.misc.extensionUtils;
const Me = ExtensionUtils.getCurrentExtension();

const AutoMuteToggleButton = GObject.registerClass(
    {GTypeName: 'AutoMuteToggleButton'},
    class AutoMuteToggleButton extends PanelMenu.Button {
        _init() {
            super._init(0.0, Me.metadata.name, false);

            this.autoMuteEnabled = true;
            this.icon = new St.Icon({
                gicon: new Gio.ThemedIcon({name: 'audio-card-symbolic'}),
                style_class: 'system-status-icon',
            });

            this.add_child(this.icon);
            this.connect('button-press-event', this.onPress.bind(this));
        }

        onPress() {
            this.autoMuteEnabled = !this.autoMuteEnabled;
            this.toggle();
            this.updateIcon();
        }

        toggle() {
            const value = this.autoMuteEnabled ? 'Disabled' : 'Enabled';
            GLib.spawn_async(
                '/',
                ['/usr/bin/amixer', '-c', '1', 'set', 'Auto-Mute Mode', value],
                ['LANG=C'],
                GLib.SpawnFlags.STDOUT_TO_DEV_NULL,
                null,
            );
        }

        updateIcon() {
            this.icon.icon_name = this.autoMuteEnabled
                ? 'audio-card-symbolic'
                : 'audio-headphones-symbolic';
        }
    },
);

let button = null;

function enable() {
    button = new AutoMuteToggleButton();
    Main.panel.addToStatusArea(Me.metadata.name, button);
}

function disable() {
    if (button !== null) {
        button.destroy();
        button = null;
    }
}

